import type { IConstruct } from "constructs";
import type { CommonActionProps } from "../action";
import { Action } from "../action";
import { RegularStep } from "../step";
/**
 * Output structure for the Setup Go action.
 *
 * Provides outputs related to the Go setup process, such as
 * the installed Go version and cache hit status.
 */
export interface SetupGoV5Outputs {
    /**
     * The version of Go that has been installed.
     */
    readonly goVersion: string;
    /**
     * A boolean value indicating whether a cache entry was found during the setup.
     */
    readonly cacheHit: string;
}
/**
 * Properties for configuring the Setup Go action.
 *
 * This interface defines the specific options for Go setup, including
 * version, caching, and target architecture.
 */
export interface SetupGoV5Props extends CommonActionProps {
    /**
     * The version range or exact version of Go to use.
     * If not specified, the action will read the version from the `go-version` file if it exists.
     */
    readonly goVersion: string;
    /**
     * Optional file containing the Go version to use.
     * Typically this would be `go-version`.
     */
    readonly goVersionFile?: string;
    /**
     * If true, the action will check for the latest available version that satisfies the specified version.
     *
     * @default false
     */
    readonly checkLatest?: boolean;
    /**
     * Token used for authentication when fetching Go distributions from the repository.
     */
    readonly token?: string;
    /**
     * A boolean indicating whether to cache Go dependencies.
     *
     * @default true
     */
    readonly cache?: boolean;
    /**
     * Path to dependency files for caching. Supports wildcards or a list of file names.
     * This allows caching of multiple dependencies efficiently.
     */
    readonly cacheDependencyPath?: string;
    /**
     * Target architecture of the Go interpreter.
     * Supported values include "amd64", "arm64", etc.
     */
    readonly architecture?: string;
}
/**
 * Class representing the Setup Go action in a GitHub Actions workflow.
 *
 * This action supports Go version setup, dependency caching, and architecture targeting.
 */
export declare class SetupGoV5 extends Action {
    readonly goVersion: string;
    readonly goVersionFile?: string;
    readonly checkLatest: boolean;
    readonly token?: string;
    readonly cache: boolean;
    readonly cacheDependencyPath?: string;
    readonly architecture?: string;
    /**
     * Initializes a new instance of the `SetupGo` action with the specified properties.
     *
     * @param scope - Scope in which this construct is defined.
     * @param id - Unique identifier for the action within a workflow.
     * @param props - Configuration properties for Go setup.
     */
    constructor(scope: IConstruct, id: string, props: SetupGoV5Props);
    /**
     * Creates a regular step for the Setup Go action.
     *
     * This method sets up the parameters for the action and prepares it to be
     * executed in the workflow.
     *
     * @returns The configured RegularStep for the GitHub Actions job.
     */
    protected createRegularStep(): RegularStep;
    /**
     * Retrieves outputs from the Setup Go action.
     *
     * This method returns an object containing output values that can be referenced in subsequent
     * steps of the workflow, including the installed Go version and cache status.
     *
     * @returns Go setup outputs, including the installed Go version and cache status.
     */
    get outputs(): SetupGoV5Outputs;
}
