import { RootConstruct } from "constructs";
import type { IManifest } from "./manifest";
import { Manifest } from "./manifest";
import type { WorkflowProps } from "./workflow";
import { Workflow } from "./workflow";
/**
 * Configuration properties for setting up a `Project` instance.
 */
export interface ProjectProps {
    /**
     * Directory for generated workflow YAML files.
     *
     * Defines the target directory where GitHub Actions workflow YAML files
     * are outputted. Defaults to `./.github/workflows` if not specified.
     *
     * @default "./.github/workflows"
     */
    readonly outdir?: string;
    /**
     * Toggle for skipping validation during synthesis.
     *
     * When `true`, skips validation of workflows. Useful for cases where
     * validation can be safely ignored.
     *
     * @default false
     */
    readonly skipValidation?: boolean;
    /**
     * Flag to enable additional workflow checks.
     *
     * When `true`, additional checks, like the `ExternalActionVersionCheck`,
     * are applied to workflows.
     *
     * @default false
     */
    readonly additionalChecks?: boolean;
    /**
     * Continue synthesis despite error annotations.
     *
     * When `true`, workflows with errors will not stop the synthesis process.
     *
     * @default false
     */
    readonly continueOnErrorAnnotations?: boolean;
}
/**
 * Represents a GitHub Actions project, managing workflows and their output.
 *
 * `Project` enables defining and synthesizing GitHub Actions workflows, converting
 * them to YAML files in the specified output directory.
 */
export declare class Project extends RootConstruct {
    /**
     * Output directory for synthesized workflow YAML files.
     */
    readonly outdir: string;
    /**
     * Flag to determine if validation is skipped during synthesis.
     */
    readonly skipValidation?: boolean;
    /**
     * Flag indicating if additional checks are applied during synthesis.
     */
    readonly additionalChecks?: boolean;
    /**
     * Flag to continue on error annotations, bypassing exit on errors.
     */
    readonly continueOnErrorAnnotations?: boolean;
    /**
     * Manifest object storing synthesized workflows for this project.
     */
    readonly manifest: Manifest;
    /**
     * Initializes a new `Project` instance.
     *
     * @param props - Configuration options, including output directory, validation, and error-handling behavior.
     */
    constructor(props?: ProjectProps);
    /**
     * Adds a workflow to the project.
     *
     * Creates and registers a new GitHub Actions workflow for this project.
     *
     * @param id - Unique identifier for the workflow.
     * @param props - Configuration properties for the workflow.
     * @returns A new `Workflow` instance added to this project.
     */
    addWorkflow(id: string, props: WorkflowProps): Workflow;
    /**
     * Synthesizes workflows into YAML files in the specified output directory.
     *
     * This method locates all workflow constructs in the project, serializes them to
     * YAML, and writes them to the output directory with a `.yml` extension.
     * It ensures the output directory exists and handles validation and error checks.
     */
    synth(): void;
}
/**
 * Pretty-prints annotations from a workflow manifest.
 *
 * @param manifest - The `IManifest` object containing workflows and their annotations.
 */
export declare function prettyPrintWorkflowManifestAnnotations(manifest: IManifest, printStacktrace?: boolean): void;
