import type { IConstruct } from "constructs";
import { Component } from "./component";
import type { Defaults } from "./defaults";
import type { Permissions } from "./permissions";
import { RegularStep, type RegularStepProps, RunStep, type RunStepProps } from "./step";
/**
 * Defines a configuration matrix for variations of a job.
 *
 * The matrix feature allows setting up multiple configurations in a job, each with
 * different parameters. GitHub Actions will create a unique job for each configuration.
 */
export interface Matrix {
    /**
     * Key-value pairs for matrix configuration, where each key can contain
     * multiple values, producing unique jobs for each combination.
     */
    readonly domain?: Record<string, string[]>;
    /**
     * Specific configurations to include in the matrix.
     * Each entry is a configuration object added to the job matrix.
     */
    readonly include?: Array<Record<string, string>>;
    /**
     * Specific configurations to exclude from the matrix.
     * Useful for avoiding certain configurations from running.
     */
    readonly exclude?: Array<Record<string, string>>;
}
/**
 * Defines a strategy for job execution, including matrix and concurrency settings.
 */
export interface Strategy {
    /**
     * Configuration matrix for job variations.
     */
    readonly matrix?: Matrix;
    /**
     * Cancels all in-progress matrix jobs if one fails.
     * @default true
     */
    readonly failFast?: boolean;
    /**
     * Limits the number of concurrent jobs in the matrix.
     */
    readonly maxParallel?: number;
}
/**
 * Credentials for authenticating with Docker registries.
 */
export interface ContainerCredentials {
    /** Docker registry username. */
    readonly username: string;
    /** Docker registry password. */
    readonly password: string;
}
/**
 * Configuration options for a Docker container used in the job.
 */
export interface ContainerOptions {
    /** Docker image to run within the job. */
    readonly image: string;
    /**
     * Credentials for container registry authentication.
     */
    readonly credentials?: ContainerCredentials;
    /**
     * Environment variables set within the container.
     */
    readonly env?: Record<string, string>;
    /**
     * Ports exposed by the container.
     */
    readonly ports?: number[];
    /**
     * Volumes attached to the container, enabling data sharing.
     * Each entry specifies a `<source>:<destinationPath>` mapping.
     */
    readonly volumes?: string[];
    /**
     * Additional Docker options for the container.
     * Refer to Docker's documentation for a list of supported options.
     *
     * @see https://docs.docker.com/engine/reference/commandline/create/#options
     */
    readonly options?: string[];
}
/**
 * Properties for configuring a GitHub Actions job.
 */
export interface JobProps {
    /** Display name for the job. */
    readonly name?: string;
    /** Environment variables for all steps in the job. */
    readonly env?: Record<string, string>;
    /** Default configuration settings for job steps. */
    readonly defaults?: Defaults;
    /** List of job dependencies that must complete before this job starts. */
    readonly needs?: string[];
    /** Permissions granted to the job. */
    readonly permissions?: Permissions;
    /** GitHub environment target for this job. */
    readonly environment?: unknown;
    /** Outputs produced by this job, accessible by downstream jobs. */
    readonly outputs?: Record<string, string>;
    /** Runner environment, e.g., "ubuntu-latest". */
    readonly runsOn?: string[] | string;
    /** Timeout duration for the job, in minutes. */
    readonly timeoutMinutes?: number;
    /** Strategy settings, including matrix configuration and concurrency limits. */
    readonly strategy?: Strategy;
    /**
     * Prevents a workflow run from failing when a job fails. Set to true to
     * allow a workflow run to pass when this job fails.
     */
    readonly continueOnError?: boolean;
    /**
     * A container to run any steps in a job that don't already specify a
     * container. If you have steps that use both script and container actions,
     * the container actions will run as sibling containers on the same network
     * with the same volume mounts.
     */
    readonly container?: ContainerOptions;
    /**
     * Used to host service containers for a job in a workflow. Service
     * containers are useful for creating databases or cache services like Redis.
     * The runner automatically creates a Docker network and manages the life
     * cycle of the service containers.
     */
    readonly services?: Record<string, ContainerOptions>;
    /** Runner labels for selecting a self-hosted runner. */
    readonly runnerLabels?: string | string[];
    /** List of checks required to pass before this job runs. */
    readonly requiredChecks?: string[];
}
/**
 * Represents a GitHub Actions job, containing configurations, steps, and dependencies.
 *
 * Jobs are composed of steps and run within a specified environment with defined
 * permissions, environment variables, and strategies.
 */
export declare class Job extends Component {
    /**
     * Checks if an object is an instance of `Job`.
     * @param x - The object to check.
     * @returns `true` if `x` is a `Job`; otherwise, `false`.
     */
    static isJob(x: unknown): x is Job;
    readonly name?: string;
    readonly env?: Record<string, string>;
    readonly defaults?: Defaults;
    readonly permissions?: Permissions;
    readonly environment?: unknown;
    readonly runsOn: string[] | string;
    readonly timeoutMinutes?: number;
    readonly strategy?: Strategy;
    readonly continueOnError?: boolean;
    readonly container?: ContainerOptions;
    readonly services?: Record<string, ContainerOptions>;
    readonly runnerLabels?: string | string[];
    readonly requiredChecks?: string[];
    private _needs;
    private _outputs?;
    /**
     * Initializes a new instance of the `Job` class.
     * @param scope - Construct scope for the job.
     * @param id - Unique identifier for the job.
     * @param props - Configuration properties for the job.
     */
    constructor(scope: IConstruct, id: string, props?: JobProps);
    /** Retrieves the unique identifier for the job. */
    get id(): string;
    /** Retrieves the job's defined outputs, if any. */
    get outputs(): Record<string, string> | undefined;
    /** Retrieves job dependencies. */
    get needs(): string[];
    /**
     * Checks if the current job contains any steps.
     *
     * This method iterates through the children of the node associated with
     * the job and checks if any of those children are instances of StepBase.
     * If at least one child is a step, the method returns true; otherwise, it
     * returns false.
     *
     * @returns True if the job has one or more steps; otherwise, false.
     */
    hasSteps(): boolean;
    /**
     * Adds an output accessible by downstream jobs.
     * @param name - Name of the output.
     * @param value - Value for the output.
     */
    addOutput(name: string, value: string): void;
    /**
     * Adds a `RunStep` to the job.
     * @param id - Unique ID for the step.
     * @param props - Properties for the `RunStep`.
     * @returns Created `RunStep` instance.
     */
    addRunStep(id: string, props: RunStepProps): RunStep;
    /**
     * Adds a `RegularStep` to the job.
     * @param id - Unique ID for the step.
     * @param props - Properties for the `RegularStep`.
     * @returns Created `RegularStep` instance.
     */
    addRegularStep(id: string, props: RegularStepProps): RegularStep;
    /**
     * Adds a dependency to another job, which must complete first.
     * @param job - Job to depend on.
     */
    addDependency(job: Job): void;
    /**
     * Serializes the job configuration for GitHub Actions YAML.
     * @returns An object representing the job configuration.
     * @internal
     * @override
     */
    _toRecord(): Record<string, unknown>;
}
