import type { IConstruct } from "constructs";
import type { ShellType } from "./common";
import { Component } from "./component";
/**
 * Common properties for all step types in a GitHub Actions workflow job.
 */
export interface CommonStepProps {
    /**
     * A descriptive name for the step, displayed in the GitHub Actions UI.
     * @example "Install dependencies"
     */
    readonly name?: string;
    /**
     * Conditional expression to determine if the step should run (equivalent to `if` in GitHub Actions).
     * Supports GitHub Actions expressions, e.g., `${{ success() }}`.
     * @example "${{ github.event_name == 'push' }}"
     */
    readonly condition?: string;
    /**
     * Maximum execution time for the step, in minutes.
     * @example 10
     */
    readonly timeoutMinutes?: number;
    /**
     * Whether the job should continue if this step fails.
     * @default false
     */
    readonly continueOnError?: boolean;
    /**
     * Environment variables specific to this step, overriding job-level or workflow-level variables.
     * @example { "NODE_ENV": "production" }
     */
    readonly env?: Record<string, string>;
}
/**
 * Configuration for a step that runs a shell command.
 */
export interface RunStepProps extends CommonStepProps {
    /**
     * Commands or scripts to execute in this step.
     * @example ["npm", "install"]
     */
    readonly run: string | string[];
    /**
     * Directory in which the step's command or action executes.
     * Defaults to the job's working directory if not specified.
     * @example "src/"
     */
    readonly workingDirectory?: string;
    /**
     * Shell environment for this step, allowing custom shells like `bash`, `pwsh`, etc.
     * @default "bash"
     * @example "pwsh"
     */
    readonly shell?: ShellType;
}
/**
 * Configuration for a step that uses a predefined GitHub Action.
 */
export interface RegularStepProps extends CommonStepProps {
    /**
     * GitHub Action to run, identified by repository or Docker image reference.
     * @example "actions/checkout@v2"
     */
    readonly uses: string;
    /**
     * Input parameters for the action, passed as a key-value map.
     * @example { "token": "${{ secrets.GITHUB_TOKEN }}" }
     */
    readonly parameters?: Record<string, unknown>;
}
/**
 * Base class representing a single step within a GitHub Actions job.
 */
export declare abstract class StepBase extends Component {
    /**
     * Checks if an object is an instance of `StepBase`.
     *
     * @param x - The object to check.
     * @returns `true` if `x` is a `StepBase`; otherwise, `false`.
     */
    static isStepBase(x: unknown): x is StepBase;
    readonly name?: string;
    readonly condition?: string;
    readonly env?: Record<string, string>;
    readonly continueOnError?: boolean;
    readonly timeoutMinutes?: number;
    /**
     * Creates a new `StepBase` instance.
     *
     * @param scope - The scope in which to define this construct.
     * @param id - The unique identifier for this step.
     * @param props - Configuration properties for this step.
     */
    constructor(scope: IConstruct, id: string, props: CommonStepProps);
    /**
     * Retrieves the step's unique identifier within the context of a workflow job.
     * @returns The unique identifier for this step.
     */
    get id(): string;
}
/**
 * Step that runs shell commands in a GitHub Actions job.
 */
export declare class RunStep extends StepBase {
    /**
     * Checks if an object is an instance of `RunStep`.
     *
     * @param x - The object to check.
     * @returns `true` if `x` is a `RunStep`; otherwise, `false`.
     */
    static isRunStep(x: unknown): x is RunStep;
    readonly run: string[];
    readonly workingDirectory?: string;
    readonly shell?: ShellType;
    /**
     * Creates a new `RunStep` instance.
     *
     * @param scope - The scope in which to define this construct.
     * @param id - The unique identifier for this step.
     * @param props - Configuration properties for this run step.
     */
    constructor(scope: IConstruct, id: string, props: RunStepProps);
    /**
     * Serializes the `RunStep` configuration to an object for GitHub Actions YAML output.
     *
     * Converts the run step configuration into an object format suitable for
     * GitHub Actions YAML serialization.
     *
     * @returns An object suitable for YAML serialization.
     * @internal
     * @override
     */
    _toRecord(): Record<string, unknown>;
}
/**
 * Step that runs a predefined GitHub Action within a job.
 */
export declare class RegularStep extends StepBase {
    /**
     * Checks if an object is an instance of `RegularStep`.
     *
     * @param x - The object to check.
     * @returns `true` if `x` is a `RegularStep`; otherwise, `false`.
     */
    static isRegularStep(x: unknown): x is RegularStep;
    readonly uses: string;
    readonly parameters?: Record<string, unknown>;
    /**
     * Creates a new `RegularStep` instance.
     *
     * @param scope - The scope in which to define this construct.
     * @param id - The unique identifier for this step.
     * @param props - Configuration properties for this regular step.
     */
    constructor(scope: IConstruct, id: string, props: RegularStepProps);
    /**
     * Determines if the action is an external action.
     *
     * @returns `true` if the action is an external action; otherwise, `false`.
     */
    isExternalAction(): boolean;
    /**
     * Determines if the action is a repository action.
     *
     * @returns `true` if the action is a repository action; otherwise, `false`.
     */
    isRepoAction(): boolean;
    /**
     * Determines if the action is a Docker action.
     *
     * @returns `true` if the action is a Docker action; otherwise, `false`.
     */
    isDockerAction(): boolean;
    /**
     * Serializes the `RegularStep` configuration to an object for GitHub Actions YAML output.
     *
     * Converts the step configuration into an object format suitable for
     * GitHub Actions YAML serialization.
     *
     * @returns An object suitable for YAML serialization.
     * @internal
     * @override
     */
    _toRecord(): Record<string, unknown>;
}
/**
 * Parses the external action name into its components: owner, repo, path, and ref.
 *
 * The expected format can be either:
 * - `{owner}/{repo}@{ref}` or
 * - `{owner}/{repo}/{path}@{ref}`
 *
 * @param name - The string representation of the external action name.
 * @returns An object containing the owner, repo, path (if present), and ref.
 * @throws Error if the input string is not in a valid format.
 */
export declare function parseExternalActionName(name: string): {
    owner: string;
    repo: string;
    ref: string;
    path?: string;
};
export declare function parseDockerActionName(name: string): {
    host: string;
    image: string;
    tag: string;
};
